@@ -1,4 +1,7 @@
 def create_table(table_name, fields):
+    """
+    String, Iterable --> String
+    """
     sql = "CREATE TABLE {} (".format(table_name)
     sql += ', '.join(["{} {}".format(field, fields[field]) for field in fields])
     sql += ')'
